
-- create metatable for gamemodes
local _gamemodes = {}

gamemodes = setmetatable({}, {
    __index = function(t, key)
        return _gamemodes[key]
    end,

    __newindex = function(t, key, value)
        _gamemodes[key] = value
    end,

    __pairs = function(t)
        return pairs(_gamemodes)
    end,

    __ipairs = function(t)
        local gamemodeKeys = {}
        for k in pairs(_gamemodes) do
            table.insert(gamemodeKeys, k)
        end
        table.sort(gamemodeKeys)
        local function iter(t, k)
            local i = k == nil and 0 or table.pos_of_element(gamemodeKeys, k)
            i = i + 1
            if gamemodeKeys[i] ~= nil then
                k = gamemodeKeys[i]
                local v = _gamemodes[k]
                return k, v
            end
        end
        return iter, _gamemodes, nil
    end
})

-- function to get selected gamemode
function get_current_gamemode()
	return gamemodes[gGlobalSyncTable.gamemode]
end

-- function to create a new gamemode
---@param key string
---@param name string
---@param hooks table|nil
function create_gamemode(key, name, initFunc, hooks, guide, objective, selectorImage, roundStatusHeader)
    -- safety checks (ooo super professional)
    if type(key) ~= "string" then
        log_to_console("Fall Guys: Warning: Failed to add " .. name .. " to the gamemodes table. The key provided is not a string. Aborting creation.", CONSOLE_MESSAGE_WARNING)
        return
    end

    if type(name) ~= "string" then
        log_to_console("Fall Guys: Warning: Failed to add gamemode with key " .. key .. ". The name provided is not a string. Aborting creation.", CONSOLE_MESSAGE_WARNING)
        return
    end

    if gamemodes[key] ~= nil then
        log_to_console("Fall Guys: Warning: Failed to add " .. name .. " to the gamemodes table. A gamemode with the same key already exists. Aborting creation.", CONSOLE_MESSAGE_WARNING)
        return
    end

    -- create a new entry in the gamemodes table
    gamemodes[key] = {
        name = name,
        initFunc = initFunc,
        hooks = hooks,
        guide = guide,
        objective = objective,
        selectorImage = selectorImage,
        roundStatusHeader = roundStatusHeader,
        initFuncRan = false
    }

    -- hook the hooks (slightly cursed passing in 5 paramters when almost certanly at least 1 will be nil, oh well)
    if gamemodes[key].hooks then
        for hook, func in pairs(gamemodes[key].hooks) do
            hook_event(hook, function (param1, param2, param3, param4, param5)
                if get_current_gamemode() == gamemodes[key] and (gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_WAITING
                or gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_COUNTDOWN
                or gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_ACTIVE) then
                    func(param1, param2, param3, param4, param5)
                end
            end)
        end
    end
end