
local playersEnteringHexagon = 0
local alivePlayers = {}
local spawnPoints = {
    { x = -350, y = 9200, z = 700 },
    { x = -350, y = 9200, z = -700 },
    { x = 0, y = 9200, z = -1050 },
    { x = 0, y = 9200, z = 1050 },
    { x = 1050, y = 9200, z = 0 },
    { x = -1050, y = 9200, z = 0 },
    { x = 0, y = 9200, z = 350 },
    { x = 0, y = 9200, z = -350 },
    { x = 700, y = 9200, z = -350 },
    { x = 700, y = 9200, z = 350 },
    { x = -350, y = 9200, z = 0 },
    { x = 350, y = 9200, z = 0 },
    { x = 350, y = 9200, z = -700 },
    { x = 350, y = 9200, z = 700 },
}

local function hexagon_gamemode_init()
    playersEnteringHexagon = get_alive_player_count()
    alivePlayers = get_alive_players()
    warp_to_level(LEVEL_HEXAGONE, 1, 0)
end

---@param m MarioState
local function mario_update(m)
    local np = gNetworkPlayers[m.playerIndex]
    local s = gPlayerSyncTable[m.playerIndex]

    if m.playerIndex ~= 0 then return end

    if np.currLevelNum ~= LEVEL_HEXAGONE then
        warp_to_level(LEVEL_HEXAGONE, 1, 0)
    end

    if gGlobalSyncTable.roundState ~= ROUND_STATE_GAMEMODE_ACTIVE then
        vec3f_copy(m.pos, spawnPoints[np.globalIndex + 1])
        if gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_COUNTDOWN
        or gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_WAITING then
            set_mario_action(m, ACT_FREEZE, 1)
            set_character_animation(m, MARIO_ANIM_GENERAL_FALL)
            m.faceAngle.y = m.intendedYaw
            m.marioObj.header.gfx.angle.y = m.faceAngle.y
        end
        return
    elseif m.action == ACT_FREEZE then
        set_mario_action(m, ACT_FREEFALL, 0)
    end

    if get_alive_player_count() <= 1 and network_is_server() then
        gGlobalSyncTable.roundState = ROUND_STATE_GAMEMODE_ENDED
    end

    if m.action & ACT_FLAG_SWIMMING ~= 0 then
        eliminate_me()
    end

    if m.floorHeight == m.pos.y and not m.floor.object then
        eliminate_me()
    end

    if m.action == ACT_BACKWARD_GROUND_KB or m.action == ACT_FORWARD_GROUND_KB then
        set_mario_action(m, ACT_IDLE, 0)
    end

    local eliminatedPlayers = 0

    for k, v in ipairs(alivePlayers) do
        local np = gNetworkPlayers[v]
        local s = gPlayerSyncTable[v]

        if not np.connected or s.role == ROLE_INACTIVE then
            eliminatedPlayers = eliminatedPlayers + 1
        end
    end

    set_round_status_desc(eliminatedPlayers .. "/" .. playersEnteringHexagon - 1)

    m.peakHeight = m.pos.y
end

---@param m MarioState
local function before_mario_update(m)
    if m.action == ACT_BACKWARD_AIR_KB or m.action == ACT_FORWARD_AIR_KB then
        m.forwardVel = clampf(m.forwardVel, -16, 16)
        m.vel.x = m.vel.x / 1.05
        m.vel.z = m.vel.z / 1.05
    end
end

create_gamemode("hexagon", "Hexagon", hexagon_gamemode_init, { [HOOK_MARIO_UPDATE] = mario_update, [HOOK_BEFORE_PHYS_STEP] = before_mario_update }, "Floor pieces fall away when you stand on them. Keep moving to survive longest to WIN the CROWN!", "Last One Standing!", nil, "Eliminated")