
define_custom_obj_fields({
    oHexagonSizeMultiplier = "f32"
})

E_MODEL_HEXAGON = smlua_model_util_get_id("hexagon_geo")
COL_HEXAGON = smlua_collision_util_get("hexagon_collision")

---@param o Object
local function hexagon_init(o)
    if not o.oHexagonSizeMultiplier or o.oHexagonSizeMultiplier <= 0 then o.oHexagonSizeMultiplier = 1.015 end
    if o.oBehParams <= 0 then o.oBehParams = 1 end
    o.oFlags = OBJ_FLAG_UPDATE_GFX_POS_AND_ANGLE
    o.collisionData = COL_HEXAGON
    o.oAction = 0
    o.oOpacity = 255
    o.oCollisionDistance = 410
    cur_obj_scale(o.oHexagonSizeMultiplier * 2)
end

---@param o Object
local function hexagon_loop(o)

    o.oAnimState = o.oBehParams

    if o.oAction == 0 then
        for i = 0, MAX_PLAYERS - 1 do
            if gNetworkPlayers[i].connected then
                local m = gMarioStates[i]

                if (m.floor.object == o and m.floorHeight == m.pos.y)
                or (m.wall and m.wall.object == o) then
                    o.oAction = 1
                end
            end
        end
    elseif o.oAction == 1 then
        o.oTimer = o.oTimer + 1
        o.oPosY = o.oPosY - 10
        if o.oTimer >= 2 then
            o.oAction = 2
            o.oTimer = 0
        end
    elseif o.oAction == 2 then
        o.oTimer = o.oTimer + 1
        o.oPosY = o.oPosY + 5
        o.oAnimState = o.oBehParams - 1
        o.oOpacity = o.oOpacity - (255 / 10)
        if o.oOpacity <= 0 then
            spawn_mist_particles()
            obj_mark_for_deletion(o)
        end
    end

    load_object_collision_model()
end

id_bhvHexagon = hook_behavior(nil, OBJ_LIST_SURFACE, false, hexagon_init, hexagon_loop, "bhvHexagon")

---@param o Object
local function hexagon_spawner_init(o)
    local ringCount = o.oBehParams
    local hexagonMultiplier = o.oHexagonSizeMultiplier
    local hexagonColor = o.oAnimState

    local hexagonSize = 345

    -- spawn center hexagon
    spawn_non_sync_object(id_bhvHexagon, E_MODEL_HEXAGON, o.oPosX, o.oPosY, o.oPosZ, function(hexagon)
        hexagon.oAnimState = 1
        obj_scale(hexagon, 2 * hexagonMultiplier)
    end)

    -- spawn each hexagon using fancy math :D (thanks chatgpt)
    for r = -ringCount, ringCount do
        for q = -ringCount, ringCount do
            local s = -q - r
            if math.abs(s) <= ringCount then
                local x = o.oPosX + hexagonSize * hexagonMultiplier * (q + r / 2)
                local z = o.oPosZ + hexagonSize * hexagonMultiplier * r * math.sqrt(3) / 2
                spawn_non_sync_object(id_bhvHexagon, E_MODEL_HEXAGON, x, o.oPosY, z, function(hexagon)
                    hexagon.oAnimState = hexagonColor
                    hexagon.oHexagonSizeMultiplier = hexagonMultiplier
                end)
            end
        end
    end

    obj_mark_for_deletion(o)
end

id_bhvHexagonSpawner = hook_behavior(id_bhvUnused05A8, OBJ_LIST_LEVEL, false, hexagon_spawner_init, nil)