
TEXTURE_PINK_RECT = get_texture_info("pink_rect")
TEXTURE_BLACK_RECT = get_texture_info("black_rect")
TEXTURE_ELIMINATED_BANNER = get_texture_info("eliminated_banner")
TEXTURE_QUALIFIED_BANNER = get_texture_info("qualified_banner")
TEXTURE_WAITING_FOR_HOST_BANNER = get_texture_info("waiting_for_host_banner")
TEXTURE_COUNTDOWN_3 = get_texture_info("countdown_3")
TEXTURE_COUNTDOWN_2 = get_texture_info("countdown_2")
TEXTURE_COUNTDOWN_1 = get_texture_info("countdown_1")
TEXTURE_COUNTDOWN_GO = get_texture_info("countdown_go")
TEXTURE_WINNER_RECT = get_texture_info("winner_rect")
TEXTURE_WINNER_BANNER = get_texture_info("winner_banner")
TEXTURE_LOADING_RECT = get_texture_info("loading_rect")

local roundStatusDesc = ""
local eliminationHudTimer = 0
local eliminationHudFade = 0
local qualifiedHudTimer = 0
local qualifiedHudFade = 0
local waitingHudFade = 0
local countdownTimer = 0
local loadingScreenFade = 0

function show_qualified_hud()
    qualifiedHudTimer = 3 * 30
end

function show_elimination_hud()
    eliminationHudTimer = 5 * 30
end

function begin_countdown(delay)
    if countdownTimer > 0 then return end
    countdownTimer = 4 * 30 + delay
end

local function hud_waiting_render()
    if gGlobalSyncTable.roundState == ROUND_STATE_WAITING then
        waitingHudFade = clampf(waitingHudFade + 20, 0, 255)
    else
        waitingHudFade = clampf(waitingHudFade - 20, 0, 255)
    end

    local screenWidth = djui_hud_get_screen_width()
    local rectWidth = TEXTURE_WAITING_FOR_HOST_BANNER.width

    local x = screenWidth / 2 - rectWidth / 2
    local y = 20

    djui_hud_set_color(255, 255, 255, waitingHudFade)
    djui_hud_render_texture(TEXTURE_WAITING_FOR_HOST_BANNER, x, y, 1, 1)
end

local function hud_round_status_render()

    if  gGlobalSyncTable.roundState ~= ROUND_STATE_GAMEMODE_COUNTDOWN
    and gGlobalSyncTable.roundState ~= ROUND_STATE_GAMEMODE_ACTIVE
    and gGlobalSyncTable.roundState ~= ROUND_STATE_GAMEMODE_ENDED then return end

    local screenWidth = djui_hud_get_screen_width()

    local rectWidth = 256
    local rectHeight = 256

    djui_hud_set_color(255, 255, 255, 255)
    djui_hud_render_texture_scaled(TEXTURE_PINK_RECT, 0, -30, rectWidth, rectHeight)

    local text = get_current_gamemode().objective
    local textWidth = djui_hud_measure_text(text)

    djui_hud_print_text(text, 10, 75, 1)

    djui_hud_render_texture_scaled(TEXTURE_BLACK_RECT, screenWidth - rectWidth, -30, rectWidth, rectHeight)

    text = get_current_gamemode().roundStatusHeader
    textWidth = djui_hud_measure_text(text)

    djui_hud_print_text(text, screenWidth - textWidth / 2 - rectWidth / 2, 60, 1)

    text = roundStatusDesc
    textWidth = djui_hud_measure_text(text)

    djui_hud_print_text(text, screenWidth - textWidth / 2 - rectWidth / 2, 90, 1)
end

local function hud_countdown()

    countdownTimer = countdownTimer - 1

    local countdownTexture = nil
    local timer = 0

    if countdownTimer > 4 * 30 then
        return
    elseif countdownTimer > 3 * 30 then
        timer = countdownTimer - 3 * 30
        countdownTexture = TEXTURE_COUNTDOWN_3
    elseif countdownTimer > 2 * 30 then
        timer = countdownTimer - 2 * 30
        countdownTexture = TEXTURE_COUNTDOWN_2
    elseif countdownTimer > 1 * 30 then
        timer = countdownTimer - 1 * 30
        countdownTexture = TEXTURE_COUNTDOWN_1
    else
        timer = countdownTimer
        countdownTexture = TEXTURE_COUNTDOWN_GO
    end

    local scale = 0
    local maxScale = 160
    if countdownTexture == TEXTURE_COUNTDOWN_GO then maxScale = 220 end
    local fade = 0

    if timer > 0.8 * 30 then
        scale = maxScale
        fade = linear_interpolation(timer, 255, 0, 0.8 * 30, 30)
    else
        scale = linear_interpolation(timer, 0, maxScale, 0.2 * 30, 0.8 * 30)
        if scale < 0 then scale = 0 end
        fade = 255
    end

    local screenWidth = djui_hud_get_screen_width()
    local screenHeight = djui_hud_get_screen_height()

    local x = screenWidth / 2 - scale / 2
    local y = screenHeight / 2 - scale / 2

    djui_hud_set_color(255, 255, 255, fade)
    djui_hud_render_texture_scaled(countdownTexture, x, y, scale, scale)
end

local function hud_qualified()

    if qualifiedHudTimer <= 0 then
        qualifiedHudFade = clampf(qualifiedHudFade - 20, 0, 255)
    else
        qualifiedHudFade = clampf(qualifiedHudFade + 20, 0, 255)
    end

    qualifiedHudTimer = qualifiedHudTimer - 1

    local texture = TEXTURE_QUALIFIED_BANNER

    if get_alive_player_count() <= 1 then
        texture = TEXTURE_WINNER_BANNER
    end

    local screenWidth = djui_hud_get_screen_width()
    local screenHeight = djui_hud_get_screen_height()

    local x = 0
    local y = screenHeight / 2 - 150

    djui_hud_set_color(255, 255, 255, qualifiedHudFade)
    djui_hud_render_texture(texture, x, y, screenWidth / texture.width, screenWidth / texture.width)
end

local function hud_elimination()
    if gGlobalSyncTable.roundState == ROUND_STATE_VICTORY
    or gGlobalSyncTable.roundState == ROUND_STATE_ELIMINATION then eliminationHudTimer = 0 end

    if eliminationHudTimer <= 0 then
        eliminationHudFade = clampf(eliminationHudFade - 20, 0, 255)
    else
        eliminationHudFade = clampf(eliminationHudFade + 20, 0, 255)
    end

    eliminationHudTimer = eliminationHudTimer - 1

    local screenWidth = djui_hud_get_screen_width()
    local screenHeight = djui_hud_get_screen_height()

    local x = 0
    local y = screenHeight / 2 - 150

    djui_hud_set_color(255, 255, 255, eliminationHudFade)
    djui_hud_render_texture(TEXTURE_ELIMINATED_BANNER, x, y, screenWidth / TEXTURE_ELIMINATED_BANNER.width, screenWidth / TEXTURE_ELIMINATED_BANNER.width)
end

local function hud_winner()
    if gGlobalSyncTable.roundState ~= ROUND_STATE_VICTORY then return end
    if find_active_player(true) == nil then return end

    local screenWidth = djui_hud_get_screen_width()

    local scale = 2
    local rectScale = 1.25

    local text = get_player_name(find_active_player(true)) .. " \\#FFD700\\Wins!"
    local textWidth = djui_hud_measure_text(strip_hex(text))

    local rectWidth = TEXTURE_WINNER_RECT.width * rectScale

    local x = screenWidth / 2 - rectWidth / 2
    local y = 20

    djui_hud_set_color(255, 255, 255, 255)
    djui_hud_render_texture(TEXTURE_WINNER_RECT, x, y, rectScale, rectScale)

    x = screenWidth / 2 - textWidth
    y = y + 67.5 * rectScale

    djui_hud_print_colored_text(text, x, y, scale)
end

local function hud_loading_screen()

    if gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_WAITING then
        loadingScreenFade = 255
    else
        loadingScreenFade = clampf(loadingScreenFade - 20, 0, 255)
    end

    djui_hud_set_color(59, 170, 255, loadingScreenFade)
    djui_hud_render_rect(0, 0, djui_hud_get_screen_width() + 1, djui_hud_get_screen_height() + 1)

    local scale = 0.5

    djui_hud_set_color(255, 255, 255, loadingScreenFade)
    djui_hud_render_texture(TEXTURE_LOADING_RECT, djui_hud_get_screen_width() / 2 - TEXTURE_LOADING_RECT.width / 2 * scale, djui_hud_get_screen_height() / 2 - 347 / 2 * scale, scale, scale)
end

local function hud_render()
    djui_hud_set_font(FONT_ALIASED)
    djui_hud_set_resolution(RESOLUTION_DJUI)

    hud_hide()

    hud_waiting_render()
    hud_round_status_render()
    hud_countdown()
    hud_qualified()
    hud_elimination()
    hud_winner()
    hud_loading_screen()
end

function set_round_status_desc(desc)
    roundStatusDesc = desc
end

hook_event(HOOK_ON_HUD_RENDER, hud_render)