#include <ultra64.h>
#include "sm64.h"
#include "behavior_data.h"
#include "model_ids.h"
#include "seq_ids.h"
#include "dialog_ids.h"
#include "segment_symbols.h"
#include "level_commands.h"

#include "game/level_update.h"

#include "levels/scripts.h"

#include "make_const_nonconst.h"
#include "levels/hexagone/header.h"

const LevelScript level_hexagone_entry[] = {
	INIT_LEVEL(),
	LOAD_MIO0(0x7, _hexagone_segment_7SegmentRomStart, _hexagone_segment_7SegmentRomEnd),
	LOAD_MIO0(0xa, _cloud_floor_skybox_mio0SegmentRomStart, _cloud_floor_skybox_mio0SegmentRomEnd),
	ALLOC_LEVEL_POOL(),
	MARIO(MODEL_MARIO, 0x00000001, bhvMario),

	AREA(1, hexagone_area_1),
		WARP_NODE(0x0A, LEVEL_BOB, 0x01, 0x0A, WARP_NO_CHECKPOINT),
		WARP_NODE(0xF0, LEVEL_CASTLE_GROUNDS, 0x01, 0x0A, WARP_NO_CHECKPOINT),
		WARP_NODE(0xF1, LEVEL_CASTLE_GROUNDS, 0x01, 0x0A, WARP_NO_CHECKPOINT),
		// spawn layer
		OBJECT(E_MODEL_HEXAGON, -350, 9000, 700, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 9000, -700, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 9000, -1050, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 9000, 1050, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 9000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 9000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 9000, 350, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 9000, -350, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 9000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 9000, -350, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 9000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 9000, 350, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 9000, -350, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 9000, 350, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 9000, -700, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 9000, 700, 0, 0, 0, 0x00000005, id_bhvHexagon),
		// layer 1
		OBJECT(E_MODEL_HEXAGON, 0, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 7500, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 7500, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 7500, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 7500, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 7500, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 7500, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 7500, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 7500, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 7500, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 7500, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 7500, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 7500, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 7500, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 7500, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 7500, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 7500, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 7500, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 7500, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 7500, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 7500, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 7500, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 7500, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 7500, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 7500, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 7500, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 7500, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 7500, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		// layer 2
		OBJECT(E_MODEL_HEXAGON, -1575, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 6000, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 6000, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 6000, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 6000, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 6000, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 6000, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 6000, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 6000, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 6000, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 6000, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 6000, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 6000, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 6000, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 6000, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 6000, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 6000, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 6000, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 6000, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 6000, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 6000, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 6000, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 6000, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 6000, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 6000, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 6000, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 6000, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 6000, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 6000, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 6000, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 6000, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 6000, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 6000, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 6000, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 6000, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 6000, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 6000, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 6000, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 6000, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 6000, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 6000, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 6000, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 6000, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 6000, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 6000, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		// layer 3
		OBJECT(E_MODEL_HEXAGON, -175, 4500, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 4500, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 4500, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 4500, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 4500, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 4500, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 4500, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 4500, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 4500, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 4500, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 4500, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 4500, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 4500, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 4500, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 4500, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 4500, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 4500, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 4500, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 4500, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 4500, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 4500, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 4500, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 4500, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 4500, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 4500, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 4500, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 4500, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 4500, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 4500, -1213, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 4500, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 4500, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 4500, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 4500, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 4500, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 4500, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 4500, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 4500, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 4500, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 4500, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 4500, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 4500, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 4500, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 4500, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 4500, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		// layer 4
		OBJECT(E_MODEL_HEXAGON, 0, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, 0, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, -606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, 606, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, -1213, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, 1212, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 3000, 1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, -1819, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, -2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 3000, 2425, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 3000, -303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 3000, 303, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 3000, -909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 3000, -1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 3000, 909, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 3000, 1516, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 3000, 2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 3000, -2122, 0, 0, 0, 0x00000005, id_bhvHexagon),
		// layer 5
		OBJECT(E_MODEL_HEXAGON, 0, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 1500, 0, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 1500, -303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 1500, 303, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 1500, -606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 1500, 606, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 1500, -909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 1500, 909, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 1500, -1213, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 1500, 1212, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 1500, -1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 1500, 1516, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 1500, 1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 1500, 2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 1500, -1819, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 1500, -2122, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, -2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 1500, 2425, 0, 0, 0, 0x00000003, id_bhvHexagon),
		// layer 6
		OBJECT(E_MODEL_HEXAGON, 175, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 0, -2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, -2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, 2425, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 0, 0, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 0, -303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 0, 303, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 0, -606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 0, 606, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 0, -909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 0, 909, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 0, -1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2450, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2450, 0, 1212, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 0, -1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2275, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2275, 0, 1516, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 0, 1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 175, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 525, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 875, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1225, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1575, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1925, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -175, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -525, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -875, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1225, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1575, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1925, 0, 2122, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 0, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 350, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 700, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1050, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1400, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 1750, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, 2100, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -350, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -700, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1050, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1400, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -1750, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(E_MODEL_HEXAGON, -2100, 0, -1819, 0, 0, 0, 0x00000000, id_bhvHexagon),
		OBJECT(MODEL_NONE, 5500, 9580, 0, 0, 180, 0, 0x000A0000, bhvInstantActiveWarp),
		MARIO_POS(0x01, 180, 5500, 9580, 0),
		TERRAIN(hexagone_area_1_collision),
		MACRO_OBJECTS(hexagone_area_1_macro_objs),
		SET_BACKGROUND_MUSIC(0x00, SEQ_LEVEL_SLIDE),
		TERRAIN_TYPE(TERRAIN_STONE),
		/* Fast64 begin persistent block [area commands] */
		/* Fast64 end persistent block [area commands] */
	END_AREA(),

	FREE_LEVEL_POOL(),
	MARIO_POS(0x01, 180, 5500, 9580, 0),
	CALL(0, lvl_init_or_update),
	CALL_LOOP(1, lvl_init_or_update),
	CLEAR_LEVEL(),
	SLEEP_BEFORE_EXIT(1),
	EXIT(),
};
