-- name: Hexagone
-- incompatible: gamemode
-- description: Hexagone is the hexagone gamemode found in Fall Guys! Keep moving to stay on the hexagons! Try moving fast to get hexagons down quickly, or try playing it slow to keep hexagons afloat!\n\nThis mod contains chat commands and uses the mod menu for controls! This mod also has a spectating system, so you can spectate players trying to win big!\n\nProposed by BizzareScape\nProgrammer: EmeraldLockdown\nLevel Design: Chilly

ROUND_STATE_WAITING = 0
ROUND_STATE_GAMEMODE_SELECTOR = 1
ROUND_STATE_GAMEMODE_WAITING = 2
ROUND_STATE_GAMEMODE_COUNTDOWN = 3
ROUND_STATE_GAMEMODE_ACTIVE = 4
ROUND_STATE_GAMEMODE_ENDED = 5
ROUND_STATE_ELIMINATION = 6
ROUND_STATE_VICTORY = 7

ROLE_ACTIVE = 0
ROLE_INACTIVE = 1
ROLE_SPECTATOR = 2

LEVEL_HEXAGONE = level_register("level_hexagone_entry", 0, "Hexagone", "hex", 28000, 0x28, 0x28, 0x28)

gGlobalSyncTable.gamemode = ""
gGlobalSyncTable.roundState = ROUND_STATE_WAITING

gServerSettings.nametags = false

for i = 0, MAX_PLAYERS - 1 do
    if network_is_server() then
        gPlayerSyncTable[i].role = ROLE_ACTIVE
    end
end

local timer = 0

local function server_update()
    if gGlobalSyncTable.roundState == ROUND_STATE_WAITING then
        for i = 0, MAX_PLAYERS - 1 do
            if gPlayerSyncTable[i].role ~= ROLE_SPECTATOR then
                gPlayerSyncTable[i].role = ROLE_ACTIVE
            end
        end
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_SELECTOR then
        -- simple stuff here
        timer = timer - 1

        if timer == 7 * 30 then
            gGlobalSyncTable.gamemode = get_random_gamemode_key()
        end

        if timer <= 0 then
            start_gamemode(gGlobalSyncTable.gamemode)
        end
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_WAITING then
        timer = timer - 1

        if timer <= 0 then
            local playerSyncValid = true
            for i = 0, MAX_PLAYERS - 1 do
                local np = gNetworkPlayers[i]
                local s = gPlayerSyncTable[i]

                if np.connected and s.role == ROLE_ACTIVE and not np.currAreaSyncValid then
                    playerSyncValid = false
                end
            end

            if playerSyncValid or network_player_connected_count() == 1 then
                gGlobalSyncTable.roundState = ROUND_STATE_GAMEMODE_COUNTDOWN
            end
        end
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_COUNTDOWN then
        timer = timer - 1

        if timer <= 0 then
            gGlobalSyncTable.roundState = ROUND_STATE_GAMEMODE_ACTIVE
        end
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_ACTIVE then
        -- do nothing
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_ENDED then
        timer = timer - 1

        if timer <= 0 then
            if get_alive_player_count() ~= 1 then
                gGlobalSyncTable.roundState = ROUND_STATE_ELIMINATION
            else
                gGlobalSyncTable.roundState = ROUND_STATE_VICTORY
            end
        end
    elseif gGlobalSyncTable.roundState == ROUND_STATE_ELIMINATION then
        timer = timer - 1

        gGlobalSyncTable.gamemode = ""

        if timer <= 0 then
            gGlobalSyncTable.roundState = ROUND_STATE_WAITING
        end
    elseif gGlobalSyncTable.roundState == ROUND_STATE_VICTORY then
        timer = timer - 1

        gGlobalSyncTable.gamemode = ""

        if timer <= 0 then
            gGlobalSyncTable.roundState = ROUND_STATE_WAITING
        end
    end
end

local function update()
    if network_is_server() then server_update() end

    if not get_current_gamemode() then
        for k, gamemode in pairs(gamemodes) do
            gamemode.initFuncRan = false
        end
    end
end

---@param m MarioState
local function mario_update(m)
    if m.playerIndex ~= 0 then return end

    if gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_ENDED then
        set_mario_action(m, ACT_FREEZE, 0)
    elseif m.action == ACT_FREEZE and m.actionArg ~= 1 then
        set_mario_action(m, ACT_FREEFALL, 0)
    end

    if gGlobalSyncTable.roundState == ROUND_STATE_VICTORY then
        m.pos.x = 1546
        m.pos.y = 3174
        m.pos.z = -3714
        m.faceAngle.y = 0
        m.marioObj.header.gfx.angle.y = 0
        gLakituState.mode = CAMERA_MODE_NONE
        gLakituState.defMode = CAMERA_MODE_NONE
        m.area.camera.mode = CAMERA_MODE_NONE
        m.area.camera.defMode = CAMERA_MODE_NONE
        gLakituState.pos.x = 1500
        gLakituState.pos.y = 3300
        gLakituState.pos.z = -3000
        vec3f_copy(gLakituState.curPos, gLakituState.pos)
        vec3f_copy(gLakituState.goalPos, gLakituState.pos)
        vec3f_copy(m.area.camera.pos, gLakituState.pos)
        vec3f_copy(gLakituState.focus, m.pos)
        gLakituState.focus.y = 3300
        vec3f_copy(gLakituState.curFocus, gLakituState.focus)
        vec3f_copy(gLakituState.goalFocus, gLakituState.focus)
        vec3f_copy(m.area.camera.focus, gLakituState.focus)
        gLakituState.yaw = 0
        gLakituState.oldYaw = 0
        gLakituState.nextYaw = 0
        m.area.camera.yaw = 0
        m.area.camera.nextYaw = 0
        if m.action ~= ACT_STAR_DANCE_NO_EXIT and find_active_player(true) == 0 then
            set_mario_action(m, ACT_STAR_DANCE_NO_EXIT, 0)
        elseif find_active_player(true) ~= 0 then
            set_mario_action(m, ACT_FREEZE, 0)
            m.marioObj.header.gfx.node.flags = m.marioObj.header.gfx.node.flags & ~GRAPH_RENDER_ACTIVE
        end
    end
end

local function on_mods_loaded()
    gPlayerSyncTable[0].role = ROLE_INACTIVE
end

local function allow_pvp(a, v)
    local aS = gPlayerSyncTable[a.playerIndex]
    local vS = gPlayerSyncTable[v.playerIndex]
    if aS.role ~= ROLE_ACTIVE or vS.role ~= ROLE_ACTIVE then return false end
end

local function allow_interact(m, o, intee, interacted)
    local s = gPlayerSyncTable[m.playerIndex]

    if intee == INTERACT_PLAYER then
        for i = 0, MAX_PLAYERS - 1 do
            if gNetworkPlayers[i].connected then
                local rM = gMarioStates[i]
                local rS = gPlayerSyncTable[i]

                if o == rM.marioObj and (rS.role ~= ROLE_ACTIVE or s.role ~= ROLE_ACTIVE) then return false end
            end
        end
    end
end

hook_event(HOOK_UPDATE, update)
hook_event(HOOK_MARIO_UPDATE, mario_update)
hook_event(HOOK_ON_MODS_LOADED, on_mods_loaded)
hook_event(HOOK_ALLOW_PVP_ATTACK, allow_pvp)
hook_event(HOOK_ALLOW_INTERACT, allow_interact)

-- my opinion has changed on these, I actually believe these are the greatest hooks ever created now.
hook_on_sync_table_change(gGlobalSyncTable, "roundState", nil, function (tag, oldVal, newVal)
    if oldVal == newVal then return end

    if gGlobalSyncTable.roundState == ROUND_STATE_WAITING then
        warp_to_level(LEVEL_CASTLE_GROUNDS, 1, 0)
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_SELECTOR then
        -- TODO: may be a long wait time, be sure to make the this be easily changeable when implementing this
        timer = 10 * 30
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_WAITING then
        timer = 1 * 30
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_COUNTDOWN then
        timer = 5 * 30
        begin_countdown(2 * 30)
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_ACTIVE then
        -- do nothing, handled by gamemode
    elseif gGlobalSyncTable.roundState == ROUND_STATE_GAMEMODE_ENDED then
        -- TODO: also may be long, will adjust in testing
        timer = 3 * 30
        if table.contains(get_alive_players(), 0) then
            show_qualified_hud()
        end
    elseif gGlobalSyncTable.roundState == ROUND_STATE_ELIMINATION then
        -- TODO: prob will be long, so ye
        timer = 10 * 30
    elseif gGlobalSyncTable.roundState == ROUND_STATE_VICTORY then
        -- TODO: prob will be long, so ye
        timer = 3.7 * 30
        warp_to_level(LEVEL_CASTLE_GROUNDS, 1, 0)
    end
end)

hook_on_sync_table_change(gGlobalSyncTable, "gamemode", nil, function (tag, oldVal, newVal)
    if get_current_gamemode() and not get_current_gamemode().initFuncRan then
        get_current_gamemode().initFunc()
        get_current_gamemode().initFuncRan = true
    end
end)