
ACT_SPECTATING = allocate_mario_action(ACT_FLAG_IDLE)

local target = nil

---@param m MarioState
local function mario_update(m)
    if m.playerIndex ~= 0 then return end

    if gPlayerSyncTable[0].role ~= ROLE_ACTIVE then
        set_mario_action(m, ACT_SPECTATING, 0)
    end
end

---@param m MarioState
local function act_spectating(m)

    m.marioObj.header.gfx.node.flags = m.marioObj.header.gfx.node.flags & ~GRAPH_RENDER_ACTIVE

    m.forwardVel = 0
    m.vel.x = 0
    m.vel.y = 0
    m.vel.z = 0
    m.slideVelX = 0
    m.slideVelZ = 0

    perform_air_step(m, 0)

    if m.playerIndex ~= 0 then return end

    if gPlayerSyncTable[0].role == ROLE_ACTIVE then
        m.marioObj.header.gfx.node.flags = m.marioObj.header.gfx.node.flags | GRAPH_RENDER_ACTIVE
        return set_mario_action(m, ACT_FREEFALL, 0)
    end

    local targetNp = gNetworkPlayers[target]
    local targetS = gPlayerSyncTable[target]
    local targetM = gMarioStates[target]

    if not target or not targetNp.connected or targetS.role ~= ROLE_ACTIVE then
        target = find_active_player(false)

        if not target then return end

        targetNp = gNetworkPlayers[target]
        targetS = gPlayerSyncTable[target]
        targetM = gMarioStates[target]
    end

    vec3f_copy(m.pos, targetM.pos)

    if m.controller.buttonPressed & R_JPAD ~= 0 then
        local prevTarget = target
        target = target + 1
        targetNp = gNetworkPlayers[target]
        targetS = gPlayerSyncTable[target]

        while not targetNp.connected or targetS.role ~= ROLE_ACTIVE do
            target = target + 1
            if target == MAX_PLAYERS then
                target = prevTarget
                targetNp = gNetworkPlayers[target]
                targetS = gPlayerSyncTable[target]
                break
            end

            targetNp = gNetworkPlayers[target]
            targetS = gPlayerSyncTable[target]
        end
    elseif m.controller.buttonPressed & L_JPAD ~= 0 then
        local prevTarget = target
        target = target - 1
        targetNp = gNetworkPlayers[target]
        targetS = gPlayerSyncTable[target]

        while not targetNp.connected or targetS.role ~= ROLE_ACTIVE do
            target = target - 1
            if target == -1 then
                target = prevTarget
                targetNp = gNetworkPlayers[target]
                targetS = gPlayerSyncTable[target]
                break
            end

            targetNp = gNetworkPlayers[target]
            targetS = gPlayerSyncTable[target]
        end
    end

    return 0
end

local function on_render()
    local m = gMarioStates[0]
    if m.action ~= ACT_SPECTATING then return end
    if not target then return end

    djui_hud_set_font(FONT_ALIASED)
    djui_hud_set_resolution(RESOLUTION_DJUI)

    local scale = 1.2
    local text = "You are watching:"
    local x = 10
    local y = djui_hud_get_screen_height() - 120

    djui_hud_set_color(255, 255, 255, 255)
    djui_hud_print_text(text, x, y, scale)

    y = y + 30 * scale

    text = get_player_name(target)
    djui_hud_set_color(255, 255, 255, 255)
    djui_hud_print_colored_text(text, x, y, scale)
end

hook_event(HOOK_MARIO_UPDATE, mario_update)
hook_event(HOOK_ON_HUD_RENDER, on_render)
hook_mario_action(ACT_SPECTATING, act_spectating)